package edu.mit.ll.group43.surfaceoptimization.dp.factory;

import edu.mit.ll.group43.surfaceoptimization.aircraft.MinimumSeparationCalculator;
import edu.mit.ll.group43.surfaceoptimization.aircraft.WeightClass;
import edu.mit.ll.group43.surfaceoptimization.dp.factory.cost.CostStrategy;
import edu.mit.ll.group43.surfaceoptimization.dp.factory.cost.OneGapSpotCostStrategy;

/**
 * This factory is used to have the DPSequencer carry out the One Gap
 * algorithm, which allows the aircraft currently being sequenced to
 * look back at the predicted takeoff times of the last two aircraft to
 * take off and determine if it can fit into the gap between them
 * without violating CPS, ready times, or adding delay to the second of
 * the two aircraft it is trying to fit between.
 * 
 * @author William Hawkins
 *
 */
public class OneGapSpotDPSequencerFactory extends SimpleSpotDPSequencerFactory {

	public OneGapSpotDPSequencerFactory(int cps,
			MinimumSeparationCalculator<? extends WeightClass> calc) {
		super(cps, calc);
	}

	@Override
	public CostStrategy getCostStrategy() {
		return new OneGapSpotCostStrategy(cps, calc);
	}

}
