package edu.mit.ll.group43.surfaceoptimization.dp.factory;

import edu.mit.ll.group43.surfaceoptimization.aircraft.MinimumSeparationCalculator;
import edu.mit.ll.group43.surfaceoptimization.aircraft.WeightClass;
import edu.mit.ll.group43.surfaceoptimization.dp.factory.cost.CostStrategy;
import edu.mit.ll.group43.surfaceoptimization.dp.factory.cost.SpotCostStrategy;
import edu.mit.ll.group43.surfaceoptimization.dp.factory.edge.EdgeValueStrategy;
import edu.mit.ll.group43.surfaceoptimization.dp.factory.edge.ZeroEdgeValueStrategy;
import edu.mit.ll.group43.surfaceoptimization.dp.factory.netgen.CPSNetworkGenerator;
import edu.mit.ll.group43.surfaceoptimization.dp.factory.netgen.IterativeCPSNetworkGenerator;
import edu.mit.ll.group43.surfaceoptimization.dp.factory.node.CPSNetworkNodeFactory;
import edu.mit.ll.group43.surfaceoptimization.dp.factory.node.DefaultCPSNetworkNodeFactory;
import edu.mit.ll.group43.surfaceoptimization.dp.factory.sequencerecovery.BacktrackSequenceRecoveryStrategy;
import edu.mit.ll.group43.surfaceoptimization.dp.factory.sequencerecovery.SequenceRecoveryStrategy;

/**
 * Factory implementation for a dynamic programming sequencer that
 * minimizes delay at the spot while keeping the spot release
 * and takeoff sequences the same.
 * 
 * @author William Hawkins
 *
 */
public class SimpleSpotDPSequencerFactory extends DPSequencerFactory {

	public SimpleSpotDPSequencerFactory(int cps,
			MinimumSeparationCalculator<? extends WeightClass> calc) {
		super(cps, calc);
	}

	@Override
	public CostStrategy getCostStrategy() {
		return new SpotCostStrategy(cps, calc);
	}

	@Override
	public EdgeValueStrategy getEdgeValueStrategy() {
		return new ZeroEdgeValueStrategy(calc);
	}
	
	@Override
	public CPSNetworkNodeFactory getCPSNetworkNodeFactory() {
		return new DefaultCPSNetworkNodeFactory();
	}
	
	@Override
	public SequenceRecoveryStrategy getSequenceRecoveryStrategy() {
		return new BacktrackSequenceRecoveryStrategy();
	}
	
	@Override
	public CPSNetworkGenerator getCPSNetworkGenerator() {
		return new IterativeCPSNetworkGenerator(cps,
				getCPSNetworkNodeFactory(), getEdgeValueStrategy());
	}
}