package edu.mit.ll.group43.surfaceoptimization.dp.factory.edge;

import edu.mit.ll.group43.surfaceoptimization.aircraft.MinimumSeparationCalculator;
import edu.mit.ll.group43.surfaceoptimization.aircraft.WeightClass;
import edu.mit.ll.group43.surfaceoptimization.network.dp.CPSNetworkNode;

/**
 * Classes that implement this abstract class will serve as strategies
 * for the DPSequencer to set the values of edges in the CPS network
 * based on the nodes the edge connects and possibly the calculator
 * being used to determine the minimum separation times between the last
 * aircraft of the two nodes.
 * 
 * @author William Hawkins
 *
 */
public abstract class EdgeValueStrategy {

	protected MinimumSeparationCalculator<? extends WeightClass> CALC;
	
	public EdgeValueStrategy(MinimumSeparationCalculator<? extends WeightClass> calc) {
		CALC = calc;
	}
	
	/**
	 * Inserts an edge between nodes a and b in the network and assigns
	 * it a value.
	 * 
	 * @param a
	 * @param b
	 */
	public abstract void insertEdge(CPSNetworkNode a, CPSNetworkNode b);
}
