package edu.mit.ll.group43.surfaceoptimization.dp.factory.edge;

import edu.mit.ll.group43.surfaceoptimization.aircraft.MinimumSeparationCalculator;
import edu.mit.ll.group43.surfaceoptimization.aircraft.WeightClass;
import edu.mit.ll.group43.surfaceoptimization.network.NetworkEdge;
import edu.mit.ll.group43.surfaceoptimization.network.dp.CPSNetworkNode;

/**
 * This strategy simply inserts edges between nodes with a value
 * of zero. This is used for algorithms that need to calculate
 * edge costs as they go and can't rely on static edge costs
 * determined when the network is first constructed.
 * 
 * @author William Hawkins
 *
 */
public class ZeroEdgeValueStrategy extends EdgeValueStrategy {

	public ZeroEdgeValueStrategy(
			MinimumSeparationCalculator<? extends WeightClass> calc) {
		super(calc);
	}

	/**
	 * Inserts an edge of weight 0 between a and b since
	 * edge weights are computed as the network is solved
	 * using this strategy.
	 * 
	 */
	@Override
	public void insertEdge(CPSNetworkNode a, CPSNetworkNode b) {
		NetworkEdge edge = new NetworkEdge(a, b, 0);
		a.addNextNode(edge);
		b.addPrevNode(edge);
	}
}