package edu.mit.ll.group43.surfaceoptimization.input;

import java.io.File;
import java.io.FileNotFoundException;
import java.util.Scanner;

import edu.mit.ll.group43.surfaceoptimization.Driver;
import edu.mit.ll.group43.surfaceoptimization.aircraft.Aircraft;
import edu.mit.ll.group43.surfaceoptimization.aircraft.DefaultWeightClass;

/**
 * Reads aircraft data in from a plain-text file.
 * 
 * @author William Hawkins
 *
 */
public class TextFCFSReader implements FCFSReader {

	private Scanner scanner;
	private int linenum;
	
	private final int SPOT = 0;
	private final int WEIGHT = 2;
	private final int TAXI = 1;
	
	public TextFCFSReader(String filename) throws FileNotFoundException {
		this.linenum = 0;
		this.scanner = new Scanner(new File(filename));
	}
	
	/**
	 * Creates an Aircraft from the next line in the input file and returns it,
	 * or returns null if the end of the file has been reached.
	 * 
	 */
	@Override
	public Aircraft nextAircraft() {
		if (scanner.hasNextLine()) {
			linenum ++;
			String line = scanner.nextLine();
			String[] info = line.split("[^0-9\\.]+");
			//TODO: Generalize which WeightClasses can be used
			Aircraft a = null;
			try {
				a = new Aircraft(DefaultWeightClass.values()[Integer.parseInt(info[WEIGHT])-1], linenum,
						Integer.parseInt(info[SPOT]), (int) Math.round(Double.parseDouble(info[TAXI])));
			} catch (Exception e) {
				Driver.err.println("Error at line " + linenum + " in the input file");
			}
			return a;
		}
		return null;
	}

}
