package edu.mit.ll.group43.surfaceoptimization.validator;

import java.util.ArrayList;
import java.util.Collections;

import edu.mit.ll.group43.surfaceoptimization.aircraft.Aircraft;
import edu.mit.ll.group43.surfaceoptimization.aircraft.AircraftSpotReleaseComparator;

/**
 * Validates that the given spot release sequence does not violate
 * the CPS constraint.
 * 
 * @author William Hawkins
 *
 */
public class CPSValidator implements Validator {

	private int CPS;
	private static CPSValidator val;
	
	private CPSValidator(int cps) {
		this.CPS = cps;
	}
	
	public static boolean validate(ArrayList<Aircraft> sequence, int cps) {
		return validate(sequence, sequence.get(0), cps);
	}
	
	public static boolean validate(ArrayList<Aircraft> sequence, Aircraft start, int cps) {
		if (val == null || val.CPS != cps) {
			val = new CPSValidator(cps);
		}
		return val.validate(sequence);
	}
	
	/**
	 * Validates that the given sequence does not violate this
	 * Validator's CPS constraint.
	 * 
	 */
	@Override
	public boolean validate(ArrayList<Aircraft> seq) {
		return validate(seq, seq.get(0));
	}
	
	public boolean validate(ArrayList<Aircraft> seq, Aircraft start) {
		Collections.sort(seq, AircraftSpotReleaseComparator.getInstance());
		
		int spotReleaseIndex = seq.indexOf(start) + 1;
		for (int i = spotReleaseIndex - 1; i < seq.size(); i ++) {
			if (Math.abs(seq.get(i).getFcfsIndex() - spotReleaseIndex) > CPS) {
				return false;
			}
			spotReleaseIndex ++;
		}
		return true;
	}
}
