package edu.mit.ll.group43.surfaceoptimization.input;

import java.io.FileNotFoundException;

import junit.framework.TestCase;

import org.junit.Before;
import org.junit.Test;

import edu.mit.ll.group43.surfaceoptimization.aircraft.Aircraft;
import edu.mit.ll.group43.surfaceoptimization.aircraft.DefaultWeightClass;
import edu.mit.ll.group43.surfaceoptimization.input.FCFSReader;
import edu.mit.ll.group43.surfaceoptimization.input.TextFCFSReader;

public class TestTextFCFSReader extends TestCase {

	private final String FCFS_FILE = "testdata/fcfs";
	private FCFSReader fcfsReader;
	
	@Override
	@Before
	public void setUp() {
		try {
			fcfsReader = new TextFCFSReader(FCFS_FILE);
		} catch (FileNotFoundException e) {
			e.printStackTrace();
		}
	}
	
	@Test
	public void testBadFile() {
		try {
			fcfsReader = new TextFCFSReader("thisfileisfake");
			fail(); // An exception must be thrown
		} catch (FileNotFoundException e) {
		
		} catch (Exception e) {
			fail(); // The exception must be a FileNotFoundException
		}
	}
	
	//TODO: Test a badly formed file
	
	@Test
	public void testCorrectNumberOfAircraft() throws FileNotFoundException {
		int i = 0;
		while (fcfsReader.nextAircraft() != null) {
			i ++;
		}
		assertEquals(i, 10);
	}
	
	@Test
	public void testAircraftValues() {
		Aircraft a = fcfsReader.nextAircraft();
		assertEquals(DefaultWeightClass.LARGE, a.getWeightClass());
		assertEquals(1, a.getFileIndex());
		assertEquals(1000, a.getSpotReadyTime());
	}
}
